@@ -28,7 +28,7 @@ from manilaclient import client as manila_client
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.38"
+MANILA_VERSION = "2.46"
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -41,8 +41,11 @@ MANILA_QUOTA_FIELDS = {
     "share_snapshots",
     "share_snapshot_gigabytes",
     "share_networks",
+    "share_groups",
+    "share_group_snapshots",
 }
 
+
 # UI field names do not match data field names returned, have
 # a map to convert them.
 MANILA_QUOTA_FIELDS_DATA_MAP = {
@@ -50,7 +53,9 @@ MANILA_QUOTA_FIELDS_DATA_MAP = {
     "share_gigabytes": "gigabytes",
     "share_snapshots": "snapshots",
     "share_snapshot_gigabytes": "snapshot_gigabytes",
-    "share_networks": "share_networks"
+    "share_networks": "share_networks",
+    "share_groups": "share_groups",
+    "share_group_snapshots": "share_group_snapshots",
 }
 
 
@@ -83,6 +88,7 @@ def manilaclient(request):
 
 
 def share_list(request, search_opts=None):
+    search_opts = search_opts or {}
     return manilaclient(request).shares.list(search_opts=search_opts)
 
 
@@ -110,17 +116,31 @@ def share_delete(request, share_id, share_group_id=None):
     )
 
 
-def share_update(request, share_id, name, description, is_public=''):
-    share_data = {'display_name': name, 'display_description': description}
-    if not isinstance(is_public, str):
-        is_public = str(is_public)
-    if is_public and is_public.lower() != 'none':
-        share_data['is_public'] = is_public
+def share_update(request, share_id, name, description, is_public=False):
+    share_data = {
+        'display_name': name,
+        'display_description': description,
+        'is_public': is_public
+    }
     return manilaclient(request).shares.update(share_id, **share_data)
 
 
 def share_rules_list(request, share_id):
-    return manilaclient(request).shares.access_list(share_id)
+    return manilaclient(request).share_access_rules.access_list(share_id)
+
+
+def share_rule_get(request, rule_id):
+    return manilaclient(request).share_access_rules.get(rule_id)
+
+
+def share_rule_set_metadata(request, rule, metadata):
+    return manilaclient(request).share_access_rules.set_metadata(
+        rule, metadata)
+
+
+def share_rule_unset_metadata(request, rule, keys):
+    return manilaclient(request).share_access_rules.unset_metadata(
+        rule, keys)
 
 
 def share_export_location_list(request, share_id):
@@ -132,9 +152,10 @@ def share_instance_export_location_list(request, share_instance_id):
         share_instance_id)
 
 
-def share_allow(request, share_id, access_type, access_to, access_level):
+def share_allow(request, share_id, access_type, access_to, access_level,
+                metadata=None):
     return manilaclient(request).shares.allow(
-        share_id, access_type, access_to, access_level)
+        share_id, access_type, access_to, access_level, metadata)
 
 
 def share_deny(request, share_id, rule_id):
@@ -189,8 +210,11 @@ def share_unmanage(request, share):
     return manilaclient(request).shares.unmanage(share)
 
 
-def share_extend(request, share_id, new_size):
-    return manilaclient(request).shares.extend(share_id, new_size)
+def share_resize(request, share_id, new_size, orig_size):
+    if orig_size > new_size:
+        return manilaclient(request).shares.shrink(share_id, new_size)
+    else:
+        return manilaclient(request).shares.extend(share_id, new_size)
 
 
 def share_revert(request, share, snapshot):
@@ -307,22 +331,25 @@ def security_service_get(request, sec_service_id, search_opts=None):
     return manilaclient(request).security_services.get(sec_service_id)
 
 
-def security_service_create(request, type, dns_ip=None, server=None,
+def security_service_create(request, type, dns_ip=None, ou=None, server=None,
                             domain=None, user=None, password=None, name=None,
                             description=None):
     return manilaclient(request).security_services.create(
-        type, dns_ip=dns_ip, server=server, domain=domain, user=user,
+        type, dns_ip=dns_ip, ou=ou, server=server, domain=domain, user=user,
         password=password, name=name, description=description)
 
 
-def security_service_update(request, security_service_id, dns_ip=None,
-                            server=None,
-                            domain=None, user=None, password=None, name=None,
-                            description=None):
+def security_service_update(request, security_service_id,
+                            dns_ip=None, ou=None,
+                            server=None, domain=None,
+                            password=None, user=None,
+                            name=None, description=None):
     return manilaclient(request).security_services.update(
-        security_service_id, dns_ip=dns_ip, server=server, domain=domain,
-        user=user, password=password, name=name, description=description,
-    )
+        security_service_id,
+        dns_ip=dns_ip, ou=ou,
+        server=server, domain=domain,
+        password=password, user=user,
+        name=name, description=description)
 
 
 def security_service_delete(request, security_service_id):
@@ -393,9 +420,10 @@ def share_type_get(request, share_type_id):
 
 
 def share_type_create(request, name, spec_driver_handles_share_servers,
-                      is_public=True):
+                      description=None, is_public=True):
     return manilaclient(request).share_types.create(
         name=name,
+        description=description,
         spec_driver_handles_share_servers=spec_driver_handles_share_servers,
         is_public=is_public)
 
@@ -436,12 +464,10 @@ def share_replica_list(request, share=None):
     return manilaclient(request).share_replicas.list(share)
 
 
-def share_replica_create(request, share, availability_zone,
-                         share_network=None):
+def share_replica_create(request, share, availability_zone):
     return manilaclient(request).share_replicas.create(
         share,
-        availability_zone=availability_zone,
-        share_network=share_network)
+        availability_zone=availability_zone)
 
 
 def share_replica_get(request, replica):
