@@ -33,6 +33,7 @@ class ManilaApiTests(base.APITestCase):
 
     @ddt.data(
         {},
+        None,
         {"name": "fake_share"},
         {"limit": "3"},
         {"host": "fake_share_host"},
@@ -44,8 +45,9 @@ class ManilaApiTests(base.APITestCase):
         self.assertEqual(
             self.manilaclient.shares.list.return_value, result)
 
+        expected_kwargs = kwargs or {}
         self.manilaclient.shares.list.assert_called_once_with(
-            search_opts=kwargs)
+            search_opts=expected_kwargs)
 
     def test_share_get(self):
         api.share_get(self.request, self.id)
@@ -83,12 +85,12 @@ class ManilaApiTests(base.APITestCase):
         self.manilaclient.shares.delete.assert_called_once_with(
             s_id, share_group_id=sg_id)
 
-    @ddt.data(("", "", "True"), ("share_name", "", "True"),
-              ("share_name", "share_description", "True"),
-              ("", "share_description", "True"),
-              ("", "", "False"), ("share_name", "", "False"),
-              ("share_name", "share_description", "False"),
-              ("", "share_description", "False"))
+    @ddt.data(("", "", True), ("share_name", "", True),
+              ("share_name", "share_description", True),
+              ("", "share_description", True),
+              ("", "", False), ("share_name", "", False),
+              ("share_name", "share_description", False),
+              ("", "share_description", False))
     @ddt.unpack
     def test_share_update(self, name, description, is_public):
         api.share_update(self.request, self.id, name, description, is_public)
@@ -103,9 +105,42 @@ class ManilaApiTests(base.APITestCase):
         result = api.share_rules_list(self.request, self.id)
 
         self.assertEqual(
-            self.manilaclient.shares.access_list.return_value, result)
+            self.manilaclient.share_access_rules.
+            access_list.return_value, result)
 
-        self.manilaclient.shares.access_list.assert_called_once_with(self.id)
+        self.manilaclient.share_access_rules.\
+            access_list.assert_called_once_with(self.id)
+
+    def test_share_rule_get(self):
+        result = api.share_rule_get(self.request, self.id)
+
+        self.assertEqual(
+            self.manilaclient.share_access_rules.get.
+            return_value, result)
+
+        self.manilaclient.share_access_rules.get.\
+            assert_called_once_with(self.id)
+
+    def test_share_rule_set_metadata(self):
+        fake_metadata = {
+            "aim": "testing",
+            "project": "test",
+        }
+
+        api.share_rule_set_metadata(
+            self.request, self.id, fake_metadata)
+
+        self.manilaclient.share_access_rules.\
+            set_metadata.assert_called_once_with(self.id, fake_metadata)
+
+    def test_share_rule_unset_metadata(self):
+        fake_key = "test"
+
+        api.share_rule_unset_metadata(
+            self.request, self.id, fake_key)
+
+        self.manilaclient.share_access_rules.\
+            unset_metadata.assert_called_once_with(self.id, fake_key)
 
     def test_list_share_export_locations(self):
         api.share_export_location_list(self.request, self.id)
@@ -120,19 +155,22 @@ class ManilaApiTests(base.APITestCase):
         client.share_instance_export_locations.list.assert_called_once_with(
             self.id)
 
-    @ddt.data(("ip", "10.0.0.13", "rw"), ("ip", "10.0.0.13", None),
-              ("ip", "10.0.0.13", "ro"),
-              ("user", "demo", "rw"),
-              ("user", "demo", None), ("user", "demo", "ro"),
-              ("cephx", "alice", "rw"),
-              ("cephx", "alice", None), ("cephx", "alice", "ro"))
+    @ddt.data(("ip", "10.0.0.13", "rw", {'testkey': "testval"}),
+              ("ip", "10.0.0.13", None, None),
+              ("ip", "10.0.0.13", "ro", {'key1': "val1"}),
+              ("user", "demo", "rw", {'key2': "val2"}),
+              ("user", "demo", None, None),
+              ("user", "demo", "ro", None),
+              ("cephx", "alice", "rw", {'test': "some"}),
+              ("cephx", "alice", None, None),
+              ("cephx", "alice", "ro", None))
     @ddt.unpack
-    def test_share_allow(self, access_type, access_to, access_level):
+    def test_share_allow(self, access_type, access_to, access_level, metadata):
         api.share_allow(self.request, self.id, access_type,
-                        access_to, access_level)
+                        access_to, access_level, metadata)
 
         self.manilaclient.shares.allow.assert_called_once_with(
-            self.id, access_type, access_to, access_level)
+            self.id, access_type, access_to, access_level, metadata)
 
     def test_share_deny(self):
         fake_rule_id = "fake_rule_id"
@@ -210,15 +248,18 @@ class ManilaApiTests(base.APITestCase):
             assert_called_once_with('fake_share'))
 
     # Share resize tests
-
-    def test_share_extend(self):
-        new_size = "123"
-
-        api.share_extend(self.request, self.id, new_size)
-
-        self.manilaclient.shares.extend.assert_called_once_with(
-            self.id, new_size
-        )
+    @ddt.data(("123", "78"), ("2", "5"),
+              ("75", "21"), ("0", "2"),
+              ("18", "62"), ("-1", "3"))
+    @ddt.unpack
+    def test_share_resize(self, new_size, orig_size):
+        api.share_resize(self.request, self.id, new_size, orig_size)
+        if orig_size > new_size:
+            self.manilaclient.shares.shrink.assert_called_once_with(
+                self.id, new_size)
+        else:
+            self.manilaclient.shares.extend.assert_called_once_with(
+                self.id, new_size)
 
     # Share snapshots tests
 
@@ -449,7 +490,7 @@ class ManilaApiTests(base.APITestCase):
         ("ldap", {}),
         ("kerberos", {}),
         ("ldap",
-            {"dns_ip": "8.8.8.8",
+            {"dns_ip": "8.8.8.8", "ou": "fakeOU",
              "name": "my_fake_ldap_security_service",
              "description": "LDAP security service"}),
         ("kerberos",
@@ -462,10 +503,11 @@ class ManilaApiTests(base.APITestCase):
     def test_security_service_create(self, ss_type, kwargs):
         expected_kwargs = {
             "dns_ip": None,
+            "ou": None,
             "server": None,
             "domain": None,
-            "user": None,
             "password": None,
+            "user": None,
             "name": None,
             "description": None
         }
@@ -478,33 +520,25 @@ class ManilaApiTests(base.APITestCase):
             ss_type, **expected_kwargs)
 
     @ddt.data(
-        {"dns_ip": "8.8.4.4",
+        {"dns_ip": "8.8.4.4", "ou": "testOU",
+         "server": "10.254.0.3", "domain": "None",
+         "password": "wr67p6", "user": "demo",
          "name": "my_fake_ldap_security_service_2",
          "description": "LDAP security service 2"},
-        {"server": "10.254.0.10",
-         "user": "demo", "password": "n0_m0r3_s3cr37",
+        {"dns_ip": "None", "ou": "None",
+         "server": "10.254.0.10", "domain": "None",
+         "password": "None", "user": "demo",
          "name": "my_fake_kerberos_security_service_2",
          "description": "Kerberos security service 2"}
     )
     def test_security_service_update(self, kwargs):
         sec_service_id = "fake_sec_service_id"
 
-        expected_kwargs = {
-            "dns_ip": None,
-            "server": None,
-            "domain": None,
-            "user": None,
-            "password": None,
-            "name": None,
-            "description": None
-        }
-        expected_kwargs.update(**kwargs)
-
         api.security_service_update(self.request, sec_service_id, **kwargs)
 
         mock_sec_service_update = self.manilaclient.security_services.update
         mock_sec_service_update.assert_called_once_with(
-            sec_service_id, **expected_kwargs)
+            sec_service_id, **kwargs)
 
     def test_security_service_delete(self):
         sec_service_id = "fake_sec_service_id"
@@ -632,13 +666,15 @@ class ManilaApiTests(base.APITestCase):
 
     @ddt.data({
         'shares': 24, 'gigabytes': 333, 'snapshots': 14,
-        'snapshot_gigabytes': 444, 'share_networks': 14
+        'snapshot_gigabytes': 444, 'share_networks': 14,
+        "share_groups": 30, "share_group_snapshots": 5,
     })
     @ddt.unpack
     def test_ui_data_map(self, **kwargs):
         expected_result = {
             'shares': 24, 'share_gigabytes': 333, 'share_snapshots': 14,
-            'share_snapshot_gigabytes': 444, 'share_networks': 14
+            'share_snapshot_gigabytes': 444, 'share_networks': 14,
+            "share_groups": 30, "share_group_snapshots": 5,
         }
 
         converted_result_for_ui = {}
@@ -672,24 +708,27 @@ class ManilaApiTests(base.APITestCase):
         self.manilaclient.share_types.create.assert_called_once_with(
             name=name,
             spec_driver_handles_share_servers=dhss,
+            description=None,
             is_public=True)
 
     @ddt.data(
-        (True, True),
-        (False, True),
-        (True, False),
-        (False, False),
+        (True, "fake_description", True),
+        (False, "fake_description", True),
+        (True, "fake_description", False),
+        (False, "fake_description", False),
     )
     @ddt.unpack
     def test_share_type_create_with_custom_values(
-            self, dhss, is_public):
+            self, dhss, description, is_public):
         name = 'fake_share_type_name'
 
         api.share_type_create(
-            self.request, name, dhss, is_public)
+            self.request, name, dhss, description,
+            is_public)
 
         self.manilaclient.share_types.create.assert_called_once_with(
             name=name,
+            description=description,
             spec_driver_handles_share_servers=dhss,
             is_public=is_public)
 
@@ -772,18 +811,16 @@ class ManilaApiTests(base.APITestCase):
 
         self.manilaclient.share_replicas.list.assert_called_once_with("FOO")
 
-    @ddt.data(None, "foo_share_network")
-    def test_share_replica_create(self, share_network):
+    def test_share_replica_create(self):
         share = "FOO_share"
         availability_zone = "BAR_availability_zone"
 
         api.share_replica_create(
-            self.request, share, availability_zone, share_network)
+            self.request, share, availability_zone)
 
         self.manilaclient.share_replicas.create.assert_called_once_with(
             share,
-            availability_zone=availability_zone,
-            share_network=share_network,
+            availability_zone=availability_zone
         )
 
     def test_share_replica_get(self):
